Wammu
=====

GUI for Gammu library.

.. image:: https://hosted.weblate.org/widgets/gammu/-/svg-badge.svg
    :alt: Translation status
    :target: https://hosted.weblate.org/engage/gammu/?utm_source=widget

.. image:: https://landscape.io/github/gammu/wammu/master/landscape.svg?style=flat
    :target: https://landscape.io/github/gammu/wammu/master
    :alt: Code Health

.. image:: https://img.shields.io/gratipay/Gammu.svg
    :alt: Gratipay
    :target: https://gratipay.com/Gammu/

.. image:: https://www.bountysource.com/badge/team?team_id=23177&style=bounties_received
    :alt: Bountysource
    :target: https://www.bountysource.com/teams/gammu/issues?utm_source=Gammu&utm_medium=shield&utm_campaign=bounties_received

Homepage
========

<http://wammu.eu/>

License
=======

GNU GPL version 2.

First start
===========

On first start you will be asked for setting up phone parameter. If you never
used Gammu/Wammu before, phone searching will be suggested, which should do
the job for you.

Usage
=====

First you have to connect to phone, then you can perform some operations with
it. For creating entries and importing you do not need to read things from
phone, for others you have to (surprising? :-)).

All actions with current list are accessible from context menu on each item,
you can also use keys: Enter for editing and Delete for deleting.

Backup from main menu creates backup of entries you have already retrieved
from phone.

Bug reporting
=============

Please report found bugs to <http://bugs.wammu.eu>.

Translating
===========

You can help translating Wammu to your language on translation server -
<https://hosted.weblate.org/projects/gammu/wammu/>.

Version control
===============

The development goes on in Git, main development branch is
<git://github.com/gammu/wammu.git>, you can browse it using
<https://github.com/gammu/wammu>.
